# Generated by roxygen2: do not edit by hand

S3method(blisa,SpatialExperiment)
S3method(blisa,default)
S3method(plotCCI,blisa)
S3method(plotCCI,default)
S3method(plotCCILR,blisa)
S3method(plotCCILR,default)
S3method(plotCCIsummary,blisa)
S3method(plotCCIsummary,default)
S3method(plotHotspots,blisa)
S3method(plotLRrank,blisa)
S3method(plotLRrank,data.frame)
S3method(print,blisa)
S3method(runCCI,blisa)
S3method(runCCI,default)
export(blisa)
export(computeSpatialWeights)
export(filterLRpairs)
export(hexBinCells)
export(is.blisa)
export(plotCCI)
export(plotCCILR)
export(plotCCIspatial)
export(plotCCIsummary)
export(plotHotspots)
export(plotLRrank)
export(runCCI)
importFrom(ComplexHeatmap,Heatmap)
importFrom(ComplexHeatmap,draw)
importFrom(ComplexHeatmap,rowAnnotation)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,expansion)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_sf)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guide_colorbar)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_gradientn)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_identity)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,theme_void)
importFrom(grDevices,colorRampPalette)
importFrom(grid,gpar)
importFrom(grid,unit)
importFrom(stats,setNames)
importFrom(utils,download.file)
