# blisa: Cell-cell communication using Bivariate Local Indicator of Spatial Autocorrelation

*blisa* implements functionalities to study cell-cell communication in spatial transcriptomics experiments using bivariate local indicator of spatial autocorrelation.

Install development version from GitHub
```
library(devtools)   
devtools::install_github("ChenLaboratory/blisa")
```
